@@ -1,3 +1,7 @@
+import os
+import sys
+
+
 def main():
     __author__ = "Andrea Rubbi : andrea.rubbi.98@gmail.com"
 
@@ -32,8 +36,7 @@ def main():
         # Retrieves args from parser
         args = pear_ebi.tree_emb_parser.parser()
 
-        if args.version:
-            print(f"[blue]PEAR v{pear_ebi.__version__}")
+        print(f"[blue]PEAR v{pear_ebi.__version__}")
 
         # ─── Interactive Mode ─────────────────────────────────────────────────
         if args.interactive_mode:
@@ -268,13 +271,14 @@ def main():
             if args.quality:
                 quality = True
 
-            if config["embedding"] is None:
-                report = args.report
-                if report:
-                    quality = True
-            if args.report:
-                quality = True
-                report = True
+            # if config["embedding"] is None:
+            #    report = args.report
+            #    if report:
+            #        quality = True
+            # if args.report:
+            #    quality = True
+            #    report = True
+            report = False
 
             if args.pca is not None:
                 method_embedding = "pca"
@@ -347,7 +351,7 @@ def main():
 
             # ─── Plot Embeddings ──────────────────────────────────────────
             if method_embedding is not None:
-                if args.plot or config["plot"] is not None:
+                if config["plot"] is not None:
                     config["plot"] = (
                         defaultdict(lambda: None, config["plot"])
                         if config["plot"] is not None
@@ -371,15 +375,21 @@ def main():
                         else False
                     )
 
+                    show = (
+                        config["plot"]["show"]
+                        if config["plot"]["show"] is not None
+                        else False
+                    )
+
                     if dimensions > 2:
-                        np = (
+                        name_plot = (
                             name_plot + "3D"
                             if name_plot is not None
                             else f"{method_embedding.upper()}_3D"
                         )
                         fig = SET.plot_3D(
                             method_embedding,
-                            name_plot=np,
+                            name_plot=name_plot,
                             plot_meta=plot_meta,
                             plot_set=plot_set,
                             select=select,
@@ -387,15 +397,17 @@ def main():
                             save=True,
                         )
 
-                        fig.show()
-                    np = (
+                        if show:
+                            fig.show()
+
+                    name_plot = (
                         name_plot + "2D"
                         if name_plot is not None
                         else f"{method_embedding.upper()}_2D"
                     )
                     fig = SET.plot_2D(
                         method_embedding,
-                        name_plot=np,
+                        name_plot=name_plot,
                         plot_meta=plot_meta,
                         plot_set=plot_set,
                         select=select,
@@ -403,13 +415,38 @@ def main():
                         save=True,
                     )
 
-                    fig.show()
+                    if show:
+                        fig.show()
+
+                else:
+                    if dimensions > 2:
+                        name_plot = f"{method_embedding.upper()}_3D"
+                        fig = SET.plot_3D(
+                            method_embedding,
+                            name_plot=name_plot,
+                            save=True,
+                        )
+
+                        if args.plot:
+                            fig.show()
+
+                        fig.show()
+                    name_plot = f"{method_embedding.upper()}_2D"
+                    fig = SET.plot_2D(
+                        method_embedding,
+                        name_plot=name_plot,
+                        save=True,
+                    )
+
+                    if args.plot:
+                        fig.show()
 
             # ─── Get Subset ───────────────────────────────────────────────
-            if args.subset != None:
-                fig2, fig3 = SET.get_subset(args.subset)
-                fig2.show()
-                fig3.show()
+            # if args.subset != None:
+            #    fig2, fig3 = SET.get_subset(args.subset)
+            #    fig2.show()
+            #    fig3.show()
+
     except KeyboardInterrupt:
         print("[orange1]\n- Leaving PEAR -")
 
