@@ -85,7 +85,7 @@ def hashrf(file, n_trees, output_file):
             out.close()
 
         distance_matrix.drop(distance_matrix.columns[-1], axis=1, inplace=True)
-        distance_matrix.to_csv(output_file)
+        distance_matrix.to_csv(output_file, header=False, index=False)
         return distance_matrix.values
     except:
         sys.exit("hashrf failed!")
@@ -133,7 +133,7 @@ def hashrf_weighted(file, n_trees, output_file):
             out.close()
 
         distance_matrix.drop(distance_matrix.columns[-1], axis=1, inplace=True)
-        distance_matrix.to_csv(output_file)
+        distance_matrix.to_csv(output_file, header=False, index=False)
         return distance_matrix.values
     except:
         sys.exit("hashrf failed!")
